Python script which converts junit xml file/text into the markdown representation
=================================================================================

Example usage
~~~~~~~~~~~~~

::

    junit-to-md-py report.xml

Example usage if the output is later used with cmd scripts
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

::

    junit-to-md-py report.xml --cmd-format
